.. currentmodule:: xarrera

.. _api:

API reference
=============

This page contains a auto-generated summary of ``xarrera``'s API.

Container schemas
-----------------
.. autosummary::
   :toctree: generated/

    DatasetSchema
    DataArraySchema

Component schemas
-----------------
.. autosummary::
   :toctree: generated/

    DTypeSchema
    DimsSchema
    ShapeSchema
    NameSchema
    ChunksSchema
    AttrSchema
    AttrsSchema
    CoordsSchema

Internals
---------
.. autosummary::
   :toctree: generated/

    base.BaseSchema
    SchemaError
